@@ -3,7 +3,6 @@
 
 import re, platform, os, pwd
 from puke.ToolsExec import *
-from puke.Tools import prompt
 from distutils import version
 
 
@@ -80,12 +79,8 @@ def check_package(name, compVersion = None, platform = "all"):
 		console.confirm('%s : OK (%s)' % (name,pVersion))
 	else:
 		console.error('%s : OK (%s not %s)' % (name,pVersion, compVersion))
-		resp = prompt('* Continue anyway ? [Y/N default=Y]')
-		if resp.lower().strip() == "n":
-			console.error('')
-			console.fail('Failed on version comp %s ' % name)
-		else:
-			console.confirm('%s : OK (%s)' % (name,pVersion))
+
+		console.fail('Failed on version comp %s ' % name)
 
 	return True
 
